Coverage report

|  |  | Statements |  | Branches |  | Total
--- | --- | --- | --- | --- | --- | --- | ---
File | class |  | coverage | statements | missing | excluded |  | coverage | branches | partial |  | coverage
src / kiss / agents / sorcar / sorcar.py | _StopRequested |  | 100% | 0 | 0 | 0 |  | 100% | 0 | 0 |  | 100%
src / kiss / agents / sorcar / sorcar.py | (no class) |  | 77% | 814 | 188 | 2 |  | 75% | 226 | 27 |  | 76%
Total |  |  | 77% | 814 | 188 | 2 |  | 75% | 226 | 27 |  | 76%

No items found using the specified filter.